# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import sparkworks_client
from sparkworks_client.models.resource_query_criteria_request_within_a_timeframe_api_model import ResourceQueryCriteriaRequestWithinATimeframeAPIModel  # noqa: E501
from sparkworks_client.rest import ApiException


class TestResourceQueryCriteriaRequestWithinATimeframeAPIModel(unittest.TestCase):
    """ResourceQueryCriteriaRequestWithinATimeframeAPIModel unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testResourceQueryCriteriaRequestWithinATimeframeAPIModel(self):
        """Test ResourceQueryCriteriaRequestWithinATimeframeAPIModel"""
        # FIXME: construct object with mandatory attributes with example values
        # model = sparkworks_client.models.resource_query_criteria_request_within_a_timeframe_api_model.ResourceQueryCriteriaRequestWithinATimeframeAPIModel()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
