# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import sparkworks_client
from sparkworks_client.api.unit_api_api import UnitAPIApi  # noqa: E501
from sparkworks_client.rest import ApiException


class TestUnitAPIApi(unittest.TestCase):
    """UnitAPIApi unit test stubs"""

    def setUp(self):
        self.api = sparkworks_client.api.unit_api_api.UnitAPIApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_unit(self):
        """Test case for create_unit

        Create a Unit  # noqa: E501
        """
        pass

    def test_create_unit_conversion(self):
        """Test case for create_unit_conversion

        Create a Unit Conversion  # noqa: E501
        """
        pass

    def test_delete_unit(self):
        """Test case for delete_unit

        Delete a Unit by its UUID  # noqa: E501
        """
        pass

    def test_delete_unit_conversion(self):
        """Test case for delete_unit_conversion

        Delete a Unit Conversion by its UUID  # noqa: E501
        """
        pass

    def test_get_unit_by_u_uid(self):
        """Test case for get_unit_by_u_uid

        Retrieve a Unit by its UUID  # noqa: E501
        """
        pass

    def test_get_unit_conversion_by_u_uid(self):
        """Test case for get_unit_conversion_by_u_uid

        Retrieve a Unit Conversion by its UUID  # noqa: E501
        """
        pass

    def test_list_all_unit_conversions(self):
        """Test case for list_all_unit_conversions

        Retrieve a collection of Unit Conversions  # noqa: E501
        """
        pass

    def test_list_all_units(self):
        """Test case for list_all_units

        Retrieve a collection of Units  # noqa: E501
        """
        pass

    def test_query_unit_conversions(self):
        """Test case for query_unit_conversions

        Retrieve a List of Unit Conversions by a query  # noqa: E501
        """
        pass

    def test_query_units(self):
        """Test case for query_units

        Retrieve a Unit by a query  # noqa: E501
        """
        pass

    def test_update_unit(self):
        """Test case for update_unit

        Update Unit  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
