# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import sparkworks_client
from sparkworks_client.api.gateway_api_api import GatewayAPIApi  # noqa: E501
from sparkworks_client.rest import ApiException


class TestGatewayAPIApi(unittest.TestCase):
    """GatewayAPIApi unit test stubs"""

    def setUp(self):
        self.api = sparkworks_client.api.gateway_api_api.GatewayAPIApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_count_gateways(self):
        """Test case for count_gateways

        Count Gateways  # noqa: E501
        """
        pass

    def test_create_gateway(self):
        """Test case for create_gateway

        Create a new Gateway  # noqa: E501
        """
        pass

    def test_delete_gateway(self):
        """Test case for delete_gateway

        Delete Gateway by its UUID  # noqa: E501
        """
        pass

    def test_get_gateway_resources(self):
        """Test case for get_gateway_resources

        Get the Resources of a Gateway by the Gateway UUID  # noqa: E501
        """
        pass

    def test_query_gateways(self):
        """Test case for query_gateways

        Retrieve a Gateway by a query  # noqa: E501
        """
        pass

    def test_retrieve_gateways(self):
        """Test case for retrieve_gateways

        Retrieve a Gateway by its UUID  # noqa: E501
        """
        pass

    def test_retrieve_gateways1(self):
        """Test case for retrieve_gateways1

        Retrieve a collection of Gateways  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
