# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import sparkworks_client
from sparkworks_client.api.group_api_api import GroupAPIApi  # noqa: E501
from sparkworks_client.rest import ApiException


class TestGroupAPIApi(unittest.TestCase):
    """GroupAPIApi unit test stubs"""

    def setUp(self):
        self.api = sparkworks_client.api.group_api_api.GroupAPIApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_count_groups(self):
        """Test case for count_groups

        Count Groups  # noqa: E501
        """
        pass

    def test_create_group(self):
        """Test case for create_group

        Create a new Group  # noqa: E501
        """
        pass

    def test_delete_group_branch(self):
        """Test case for delete_group_branch

        Delete Group branch by the Group UUID  # noqa: E501
        """
        pass

    def test_get_group_gateways(self):
        """Test case for get_group_gateways

        Get the Gateways of a Group by the Group UUID  # noqa: E501
        """
        pass

    def test_get_group_resources(self):
        """Test case for get_group_resources

        Get the Resources of a Group by the Group UUID  # noqa: E501
        """
        pass

    def test_get_main_level_groups(self):
        """Test case for get_main_level_groups

        List the main level Groups  # noqa: E501
        """
        pass

    def test_get_sub_groups(self):
        """Test case for get_sub_groups

        Get the Subgroups of a Group by the Group UUID  # noqa: E501
        """
        pass

    def test_move_group_branch(self):
        """Test case for move_group_branch

        Move Group Branch  # noqa: E501
        """
        pass

    def test_retrieve_group(self):
        """Test case for retrieve_group

        Retrieve a Group by its UUID  # noqa: E501
        """
        pass

    def test_retrieve_groups(self):
        """Test case for retrieve_groups

        Retrieve a collection of Groups  # noqa: E501
        """
        pass

    def test_update_group(self):
        """Test case for update_group

        Update Group  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
