# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import sparkworks_client
from sparkworks_client.api.registry_api_api import RegistryAPIApi  # noqa: E501
from sparkworks_client.rest import ApiException


class TestRegistryAPIApi(unittest.TestCase):
    """RegistryAPIApi unit test stubs"""

    def setUp(self):
        self.api = sparkworks_client.api.registry_api_api.RegistryAPIApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_query_registry(self):
        """Test case for query_registry

        Query the Registry Service to retrieve a collection of Resources records with their last read value and timestamp by their UUID  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
