# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class UnitConversionDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'method': 'str',
        'source_uuid': 'str',
        'target_uuid': 'str',
        'uuid': 'str'
    }

    attribute_map = {
        'method': 'method',
        'source_uuid': 'sourceUuid',
        'target_uuid': 'targetUuid',
        'uuid': 'uuid'
    }

    def __init__(self, method=None, source_uuid=None, target_uuid=None, uuid=None):  # noqa: E501
        """UnitConversionDTO - a model defined in Swagger"""  # noqa: E501

        self._method = None
        self._source_uuid = None
        self._target_uuid = None
        self._uuid = None
        self.discriminator = None

        if method is not None:
            self.method = method
        if source_uuid is not None:
            self.source_uuid = source_uuid
        if target_uuid is not None:
            self.target_uuid = target_uuid
        if uuid is not None:
            self.uuid = uuid

    @property
    def method(self):
        """Gets the method of this UnitConversionDTO.  # noqa: E501


        :return: The method of this UnitConversionDTO.  # noqa: E501
        :rtype: str
        """
        return self._method

    @method.setter
    def method(self, method):
        """Sets the method of this UnitConversionDTO.


        :param method: The method of this UnitConversionDTO.  # noqa: E501
        :type: str
        """

        self._method = method

    @property
    def source_uuid(self):
        """Gets the source_uuid of this UnitConversionDTO.  # noqa: E501


        :return: The source_uuid of this UnitConversionDTO.  # noqa: E501
        :rtype: str
        """
        return self._source_uuid

    @source_uuid.setter
    def source_uuid(self, source_uuid):
        """Sets the source_uuid of this UnitConversionDTO.


        :param source_uuid: The source_uuid of this UnitConversionDTO.  # noqa: E501
        :type: str
        """

        self._source_uuid = source_uuid

    @property
    def target_uuid(self):
        """Gets the target_uuid of this UnitConversionDTO.  # noqa: E501


        :return: The target_uuid of this UnitConversionDTO.  # noqa: E501
        :rtype: str
        """
        return self._target_uuid

    @target_uuid.setter
    def target_uuid(self, target_uuid):
        """Sets the target_uuid of this UnitConversionDTO.


        :param target_uuid: The target_uuid of this UnitConversionDTO.  # noqa: E501
        :type: str
        """

        self._target_uuid = target_uuid

    @property
    def uuid(self):
        """Gets the uuid of this UnitConversionDTO.  # noqa: E501


        :return: The uuid of this UnitConversionDTO.  # noqa: E501
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """Sets the uuid of this UnitConversionDTO.


        :param uuid: The uuid of this UnitConversionDTO.  # noqa: E501
        :type: str
        """

        self._uuid = uuid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UnitConversionDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UnitConversionDTO):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
