# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import sparkworks_client
from sparkworks_client.api.data_api_api import DataAPIApi  # noqa: E501
from sparkworks_client.rest import ApiException


class TestDataAPIApi(unittest.TestCase):
    """DataAPIApi unit test stubs"""

    def setUp(self):
        self.api = sparkworks_client.api.data_api_api.DataAPIApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_publish_data_using_post(self):
        """Test case for publish_data_using_post

        publishData  # noqa: E501
        """
        pass

    def test_query_latest_summary_for_resources_using_post(self):
        """Test case for query_latest_summary_for_resources_using_post

        queryLatestSummaryForResources  # noqa: E501
        """
        pass

    def test_query_latest_values_for_resources_using_post(self):
        """Test case for query_latest_values_for_resources_using_post

        queryLatestValuesForResources  # noqa: E501
        """
        pass

    def test_query_time_range_using_post(self):
        """Test case for query_time_range_using_post

        queryTimeRange  # noqa: E501
        """
        pass

    def test_retrieve_latest_summary_using_get(self):
        """Test case for retrieve_latest_summary_using_get

        retrieveLatestSummary  # noqa: E501
        """
        pass

    def test_retrieve_latest_values_using_get(self):
        """Test case for retrieve_latest_values_using_get

        retrieveLatestValues  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
