# coding: utf-8

# flake8: noqa
"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from sparkworks_client.models.a_participatory_sensing_resource_request_api_model import AParticipatorySensingResourceRequestAPIModel
from sparkworks_client.models.collection_of_data_query_criteria_request_api_model import CollectionOfDataQueryCriteriaRequestAPIModel
from sparkworks_client.models.command_api_model import CommandAPIModel
from sparkworks_client.models.gateway_create_dto import GatewayCreateDTO
from sparkworks_client.models.gateway_dto import GatewayDTO
from sparkworks_client.models.gateway_query_dto import GatewayQueryDTO
from sparkworks_client.models.group_create_dto import GroupCreateDTO
from sparkworks_client.models.group_dto import GroupDTO
from sparkworks_client.models.group_node_dto import GroupNodeDTO
from sparkworks_client.models.group_update_dto import GroupUpdateDTO
from sparkworks_client.models.list_of_participatory_sensing_data_api_model import ListOfParticipatorySensingDataAPIModel
from sparkworks_client.models.list_of_query_criteria_within_a_timeframe_request_api_model import ListOfQueryCriteriaWithinATimeframeRequestAPIModel
from sparkworks_client.models.participatory_sensing_data_api_model import ParticipatorySensingDataAPIModel
from sparkworks_client.models.phenomenon_create_dto import PhenomenonCreateDTO
from sparkworks_client.models.phenomenon_dto import PhenomenonDTO
from sparkworks_client.models.phenomenon_query_dto import PhenomenonQueryDTO
from sparkworks_client.models.phenomenon_update_dto import PhenomenonUpdateDTO
from sparkworks_client.models.registry_pair_dto import RegistryPairDTO
from sparkworks_client.models.registry_record_dto import RegistryRecordDTO
from sparkworks_client.models.resource_analytics_data_response_api_model import ResourceAnalyticsDataResponseAPIModel
from sparkworks_client.models.resource_create_dto import ResourceCreateDTO
from sparkworks_client.models.resource_dto import ResourceDTO
from sparkworks_client.models.resource_latest_data_response_api_model import ResourceLatestDataResponseAPIModel
from sparkworks_client.models.resource_latest_values_response_api_model import ResourceLatestValuesResponseAPIModel
from sparkworks_client.models.resource_query_criteria_request_api_model import ResourceQueryCriteriaRequestAPIModel
from sparkworks_client.models.resource_query_criteria_request_within_a_timeframe_api_model import ResourceQueryCriteriaRequestWithinATimeframeAPIModel
from sparkworks_client.models.resource_query_criteria_within_a_timeframe_response_api_model import ResourceQueryCriteriaWithinATimeframeResponseAPIModel
from sparkworks_client.models.resource_query_dto import ResourceQueryDTO
from sparkworks_client.models.resource_update_dto import ResourceUpdateDTO
from sparkworks_client.models.single_resource_measurement_api_model import SingleResourceMeasurementAPIModel
from sparkworks_client.models.the_resource_summary_data_api_model import TheResourceSummaryDataAPIModel
from sparkworks_client.models.unit_conversion_create_dto import UnitConversionCreateDTO
from sparkworks_client.models.unit_conversion_dto import UnitConversionDTO
from sparkworks_client.models.unit_conversion_query_dto import UnitConversionQueryDTO
from sparkworks_client.models.unit_create_dto import UnitCreateDTO
from sparkworks_client.models.unit_dto import UnitDTO
from sparkworks_client.models.unit_query_dto import UnitQueryDTO
from sparkworks_client.models.unit_update_dto import UnitUpdateDTO
