# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import sparkworks_client
from sparkworks_client.api.phenomenon_api_api import PhenomenonAPIApi  # noqa: E501
from sparkworks_client.rest import ApiException


class TestPhenomenonAPIApi(unittest.TestCase):
    """PhenomenonAPIApi unit test stubs"""

    def setUp(self):
        self.api = sparkworks_client.api.phenomenon_api_api.PhenomenonAPIApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_phenomenon(self):
        """Test case for create_phenomenon

        Create a Phenomenon  # noqa: E501
        """
        pass

    def test_delete_phenomenon(self):
        """Test case for delete_phenomenon

        Delete a Phenomenon by its UUID  # noqa: E501
        """
        pass

    def test_get_phenomenon_by_u_uid(self):
        """Test case for get_phenomenon_by_u_uid

        Retrieve a Phenomenon by its UUID  # noqa: E501
        """
        pass

    def test_list_all_phenomenons(self):
        """Test case for list_all_phenomenons

        Retrieve a collection of Phenomenons  # noqa: E501
        """
        pass

    def test_query_phenomenons(self):
        """Test case for query_phenomenons

        Retrieve a Phenomenon by a query  # noqa: E501
        """
        pass

    def test_update_phenomenon(self):
        """Test case for update_phenomenon

        Update Phenomenon  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
