# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import sparkworks_client
from sparkworks_client.api.resource_api_api import ResourceAPIApi  # noqa: E501
from sparkworks_client.rest import ApiException


class TestResourceAPIApi(unittest.TestCase):
    """ResourceAPIApi unit test stubs"""

    def setUp(self):
        self.api = sparkworks_client.api.resource_api_api.ResourceAPIApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_count_resourmvnces(self):
        """Test case for count_resourmvnces

        Count Resources  # noqa: E501
        """
        pass

    def test_create_resource(self):
        """Test case for create_resource

        Create a new Resource  # noqa: E501
        """
        pass

    def test_delete_resource(self):
        """Test case for delete_resource

        Delete Resource by its UUID  # noqa: E501
        """
        pass

    def test_move_resource(self):
        """Test case for move_resource

        Move Resource by its UUID  # noqa: E501
        """
        pass

    def test_query_resources(self):
        """Test case for query_resources

        Retrieve a Resource by a query  # noqa: E501
        """
        pass

    def test_retrieve_resource(self):
        """Test case for retrieve_resource

        Retrieve a Spark Works Resource by its UUID  # noqa: E501
        """
        pass

    def test_retrieve_resources(self):
        """Test case for retrieve_resources

        Retrieve a collection of Resources  # noqa: E501
        """
        pass

    def test_update_resource(self):
        """Test case for update_resource

        Update Resource  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
