# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class GroupDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_by': 'str',
        'created_date': 'datetime',
        'deleted': 'bool',
        'last_modified_by': 'str',
        'last_modified_date': 'datetime',
        'name': 'str',
        'parent_path': 'str',
        'path': 'str',
        'uuid': 'str'
    }

    attribute_map = {
        'created_by': 'createdBy',
        'created_date': 'createdDate',
        'deleted': 'deleted',
        'last_modified_by': 'lastModifiedBy',
        'last_modified_date': 'lastModifiedDate',
        'name': 'name',
        'parent_path': 'parentPath',
        'path': 'path',
        'uuid': 'uuid'
    }

    def __init__(self, created_by=None, created_date=None, deleted=None, last_modified_by=None, last_modified_date=None, name=None, parent_path=None, path=None, uuid=None):  # noqa: E501
        """GroupDTO - a model defined in Swagger"""  # noqa: E501

        self._created_by = None
        self._created_date = None
        self._deleted = None
        self._last_modified_by = None
        self._last_modified_date = None
        self._name = None
        self._parent_path = None
        self._path = None
        self._uuid = None
        self.discriminator = None

        if created_by is not None:
            self.created_by = created_by
        if created_date is not None:
            self.created_date = created_date
        if deleted is not None:
            self.deleted = deleted
        if last_modified_by is not None:
            self.last_modified_by = last_modified_by
        if last_modified_date is not None:
            self.last_modified_date = last_modified_date
        if name is not None:
            self.name = name
        if parent_path is not None:
            self.parent_path = parent_path
        if path is not None:
            self.path = path
        if uuid is not None:
            self.uuid = uuid

    @property
    def created_by(self):
        """Gets the created_by of this GroupDTO.  # noqa: E501


        :return: The created_by of this GroupDTO.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this GroupDTO.


        :param created_by: The created_by of this GroupDTO.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def created_date(self):
        """Gets the created_date of this GroupDTO.  # noqa: E501


        :return: The created_date of this GroupDTO.  # noqa: E501
        :rtype: datetime
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this GroupDTO.


        :param created_date: The created_date of this GroupDTO.  # noqa: E501
        :type: datetime
        """

        self._created_date = created_date

    @property
    def deleted(self):
        """Gets the deleted of this GroupDTO.  # noqa: E501


        :return: The deleted of this GroupDTO.  # noqa: E501
        :rtype: bool
        """
        return self._deleted

    @deleted.setter
    def deleted(self, deleted):
        """Sets the deleted of this GroupDTO.


        :param deleted: The deleted of this GroupDTO.  # noqa: E501
        :type: bool
        """

        self._deleted = deleted

    @property
    def last_modified_by(self):
        """Gets the last_modified_by of this GroupDTO.  # noqa: E501


        :return: The last_modified_by of this GroupDTO.  # noqa: E501
        :rtype: str
        """
        return self._last_modified_by

    @last_modified_by.setter
    def last_modified_by(self, last_modified_by):
        """Sets the last_modified_by of this GroupDTO.


        :param last_modified_by: The last_modified_by of this GroupDTO.  # noqa: E501
        :type: str
        """

        self._last_modified_by = last_modified_by

    @property
    def last_modified_date(self):
        """Gets the last_modified_date of this GroupDTO.  # noqa: E501


        :return: The last_modified_date of this GroupDTO.  # noqa: E501
        :rtype: datetime
        """
        return self._last_modified_date

    @last_modified_date.setter
    def last_modified_date(self, last_modified_date):
        """Sets the last_modified_date of this GroupDTO.


        :param last_modified_date: The last_modified_date of this GroupDTO.  # noqa: E501
        :type: datetime
        """

        self._last_modified_date = last_modified_date

    @property
    def name(self):
        """Gets the name of this GroupDTO.  # noqa: E501


        :return: The name of this GroupDTO.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this GroupDTO.


        :param name: The name of this GroupDTO.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def parent_path(self):
        """Gets the parent_path of this GroupDTO.  # noqa: E501


        :return: The parent_path of this GroupDTO.  # noqa: E501
        :rtype: str
        """
        return self._parent_path

    @parent_path.setter
    def parent_path(self, parent_path):
        """Sets the parent_path of this GroupDTO.


        :param parent_path: The parent_path of this GroupDTO.  # noqa: E501
        :type: str
        """

        self._parent_path = parent_path

    @property
    def path(self):
        """Gets the path of this GroupDTO.  # noqa: E501


        :return: The path of this GroupDTO.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this GroupDTO.


        :param path: The path of this GroupDTO.  # noqa: E501
        :type: str
        """

        self._path = path

    @property
    def uuid(self):
        """Gets the uuid of this GroupDTO.  # noqa: E501


        :return: The uuid of this GroupDTO.  # noqa: E501
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """Sets the uuid of this GroupDTO.


        :param uuid: The uuid of this GroupDTO.  # noqa: E501
        :type: str
        """

        self._uuid = uuid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GroupDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GroupDTO):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
